\name{bsa.fast}
\alias{bsa.fast}
\title{
Calculating broad sense agreement coefficient the jackknife standard deviation for one time point based on empricial survival function
}
\description{
This function is used for calculating broad sense agreement coefficient between an ordinal variable and a continuous variable with one time point, and its jackknife standard deviation based on empricial survival function.
}
\usage{
  bsa.fast(data,status,x.level)
}
\arguments{
  \item{data}{
    A matrix or data.frame with 2 columns. The first column is a vector of the ordinal variable x. The second column is a vector of the continuous variable y.
  }
  \item{status}{
    A vector of indicator of censored status of y. 1 indicates y is observed, and 0 indicates y is censored.
  }
  \item{x.level}{
    A numeric vector indicating the levels of ordinal variable x.
  }
}

\value{
  \emph{bsa} returns a list containing the following components:
  \item{bsa}{the estimated broad sense agreement coefficient.}
  \item{sd}{the jackknife standard deviation.}
  \item{flag}{0 means no data for at least one level of x and bsa and sd are both NA. flag=1 means every level has data.}
}
\author{
  Bo Wei
}
\references{
  Wei, B., Dai, T., Peng, L., Guo, Y. and Manatunga, A., 2020. A new functional representation of broad sense agreement. Statistics & Probability Letters, 158, p.108619.
}\examples{
  N=40
  x=sample(1:3,N,replace=TRUE)
  y=rnorm(N,sd=0.8)+x
  x.level<-1:3
  bsa.fast(cbind(x,y),rep(1,N),x.level)
}
