\title{
Calculating broad sense agreement coefficient for longitudinal data
}\name{lbsa}\alias{lbsa}\description{
This function is used for calculating broad sense agreement coefficient between ordinal variable and continuous variable with longitudinal settings.
}\usage{
lbsa(x,y,x.level)
}\arguments{
\item{x}{
A matrix or data.frame indicating the ordinal variable, with at least 2 columns.
}
\item{y}{
A matrix or data.frame indicating the continuous variable, with at least 2 columns.
}
\item{x.level}{
A numeric vector indicating the levels of ordinal variable x.
}
}
\value{
\emph{lbsa} returns a list containing the following components:
\item{est.bsa}{the estimated BSA.}
\item{Dn.ori}{Dn.ori=sqrt(n)*t(p_2-p_1,...,p_m-p_1), where n is sample size, t() means transpose of a vector,
                      p_i means the estimated BSA at time i and m is the number of time point.}
\item{Dn.fisher}{Dn.fisher=sqrt(n)*t(f(p_2)-f(p_1),...,f(p_m)-f(p_1)), where n is sample size, t() means transpose of a vector, f is a transformation function with f(x)=0.5*log((1+x)/(1-x)),p_i means the estimated BSA at time point i and m is the number of time point.}
\item{var.ori}{var.ori is the jackknife estimator of Dn.ori.}
\item{var.jack.fisher}{var.jack.fisher is the estimated covariance matrix of Dn.fisher.}
\item{T}{the value of test statistic.}
\item{indx}{the number of estimated BSA equals 1 or -1.}
You could see the definition of the above on the reference paper part 2.5. Dn.ori is Rn in the paper. Dn.fisher is Dn in the paper. var.ori is Vn in the paper.
var.jack.fisher is the Sigma_n in the paper.
}\author{
Qingpo Cai
}\references{
Peng, L., Li, R., Guo, Y., and Manatunga, A.
A Framework for Assessing Broad Sense Agreement Between Ordinal and Continuous Measurements
Journal of the American Statistical Association, 106: 1592--1601, 2011.
}\examples{
N=40
x=sample(1:3,N,replace=TRUE)
y=rnorm(N,sd=0.8)+x
x1<-sample(1:3,N,replace=TRUE)
y1<-rnorm(N,sd=1)+x1
x2<-cbind(x,x1)
y2<-cbind(y,y1)
x.level=1:3
lbsa(x2,y2,x.level)
}
